==> zio-aws-sesv2_3-5.17.124.3-sources.jar: zio/aws/sesv2/model/EmailContent.scala <==
package zio.aws.sesv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class EmailContent(
    simple: Option[zio.aws.sesv2.model.Message] = None,
    raw: Option[zio.aws.sesv2.model.RawMessage] = None,
    template: Option[zio.aws.sesv2.model.Template] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sesv2.model.EmailContent = {
    import EmailContent.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sesv2.model.EmailContent
      .builder()
      .optionallyWith(simple.map(value => value.buildAwsValue()))(_.simple)
      .optionallyWith(raw.map(value => value.buildAwsValue()))(_.raw)
      .optionallyWith(template.map(value => value.buildAwsValue()))(_.template)
      .build()
  }
  def asReadOnly: zio.aws.sesv2.model.EmailContent.ReadOnly =
    zio.aws.sesv2.model.EmailContent.wrap(buildAwsValue())
}
object EmailContent {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sesv2.model.EmailContent
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sesv2.model.EmailContent =
      zio.aws.sesv2.model.EmailContent(
        simple.map(value => value.asEditable),
        raw.map(value => value.asEditable),
        template.map(value => value.asEditable)
      )
    def simple: Option[zio.aws.sesv2.model.Message.ReadOnly]
    def raw: Option[zio.aws.sesv2.model.RawMessage.ReadOnly]
    def template: Option[zio.aws.sesv2.model.Template.ReadOnly]
    def getSimple: ZIO[Any, AwsError, zio.aws.sesv2.model.Message.ReadOnly] =
      AwsError.unwrapOptionField("simple", simple)
    def getRaw: ZIO[Any, AwsError, zio.aws.sesv2.model.RawMessage.ReadOnly] =
      AwsError.unwrapOptionField("raw", raw)
    def getTemplate: ZIO[Any, AwsError, zio.aws.sesv2.model.Template.ReadOnly] =
      AwsError.unwrapOptionField("template", template)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sesv2.model.EmailContent
  ) extends zio.aws.sesv2.model.EmailContent.ReadOnly {
    override val simple: Option[zio.aws.sesv2.model.Message.ReadOnly] = scala
      .Option(impl.simple())
      .map(value => zio.aws.sesv2.model.Message.wrap(value))
    override val raw: Option[zio.aws.sesv2.model.RawMessage.ReadOnly] = scala
      .Option(impl.raw())
      .map(value => zio.aws.sesv2.model.RawMessage.wrap(value))
    override val template: Option[zio.aws.sesv2.model.Template.ReadOnly] = scala
      .Option(impl.template())
      .map(value => zio.aws.sesv2.model.Template.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sesv2.model.EmailContent
  ): zio.aws.sesv2.model.EmailContent.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sesv2_3-6.20.78.1-sources.jar: zio/aws/sesv2/model/EmailContent.scala <==
package zio.aws.sesv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class EmailContent(
    simple: Optional[zio.aws.sesv2.model.Message] = Optional.Absent,
    raw: Optional[zio.aws.sesv2.model.RawMessage] = Optional.Absent,
    template: Optional[zio.aws.sesv2.model.Template] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sesv2.model.EmailContent = {
    import EmailContent.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sesv2.model.EmailContent
      .builder()
      .optionallyWith(simple.map(value => value.buildAwsValue()))(_.simple)
      .optionallyWith(raw.map(value => value.buildAwsValue()))(_.raw)
      .optionallyWith(template.map(value => value.buildAwsValue()))(_.template)
      .build()
  }
  def asReadOnly: zio.aws.sesv2.model.EmailContent.ReadOnly =
    zio.aws.sesv2.model.EmailContent.wrap(buildAwsValue())
}
object EmailContent {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sesv2.model.EmailContent
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sesv2.model.EmailContent =
      zio.aws.sesv2.model.EmailContent(
        simple.map(value => value.asEditable),
        raw.map(value => value.asEditable),
        template.map(value => value.asEditable)
      )
    def simple: Optional[zio.aws.sesv2.model.Message.ReadOnly]
    def raw: Optional[zio.aws.sesv2.model.RawMessage.ReadOnly]
    def template: Optional[zio.aws.sesv2.model.Template.ReadOnly]
    def getSimple: ZIO[Any, AwsError, zio.aws.sesv2.model.Message.ReadOnly] =
      AwsError.unwrapOptionField("simple", simple)
    def getRaw: ZIO[Any, AwsError, zio.aws.sesv2.model.RawMessage.ReadOnly] =
      AwsError.unwrapOptionField("raw", raw)
    def getTemplate: ZIO[Any, AwsError, zio.aws.sesv2.model.Template.ReadOnly] =
      AwsError.unwrapOptionField("template", template)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sesv2.model.EmailContent
  ) extends zio.aws.sesv2.model.EmailContent.ReadOnly {
    override val simple: Optional[zio.aws.sesv2.model.Message.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.simple())
        .map(value => zio.aws.sesv2.model.Message.wrap(value))
    override val raw: Optional[zio.aws.sesv2.model.RawMessage.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.raw())
        .map(value => zio.aws.sesv2.model.RawMessage.wrap(value))
    override val template: Optional[zio.aws.sesv2.model.Template.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.template())
        .map(value => zio.aws.sesv2.model.Template.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sesv2.model.EmailContent
  ): zio.aws.sesv2.model.EmailContent.ReadOnly = new Wrapper(impl)
}
